@@ -1,6 +1,6 @@
 
 meboot.pdata.frame <- function(x, reps=999, trim=0.10, reachbnd=TRUE,
-  expand.sd=TRUE, force.clt=TRUE, elaps=FALSE, 
+  expand.sd=TRUE, force.clt=TRUE, scl.adjustment = FALSE, sym = FALSE, elaps=FALSE,
   colsubj, coldata, coltimes, ...)
 {
   ref1 <- x[,colsubj]
@@ -11,14 +11,15 @@ meboot.pdata.frame <- function(x, reps=999, trim=0.10, reachbnd=TRUE,
     ir <- which(ref1==ref2[i])
     xs <- x[ir,coldata]  
     bxs <- meboot(xs, reps=reps, trim=0.10, reachbnd=reachbnd,
-      expand.sd=expand.sd, force.clt=force.clt, elaps=elaps, ...)
+      expand.sd=expand.sd, force.clt=force.clt, scl.adjustment=scl.adjustment, sym=sym, 
+      elaps=elaps, ...)
     xens <- rbind(xens, bxs$ensemble) 
   }
 
   xens <- data.frame(xens)
-  dimnames(xens)[[2]] <- paste("Pseries", 1:reps)
+  dimnames(xens)[[2]] <- paste("Pseries", seq.int(reps))
   if(!missing(coltimes))
-    dimnames(xens)[[1]] <- paste("Series", 1:reps, x[,coltimes])
+    dimnames(xens)[[1]] <- paste("Series", seq.int(reps), x[,coltimes])
 
   xens
 }
